"use strict";
/**
 * @file Fonctions qui implémentent les requetes relatives aux requetes
 * @author ofacklam
 * @memberof GraphQL
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const requests_1 = require("../object_resolvers/requests");
class RequestModel {
    /**
     * @memberof GraphQL
     * @class RequestModel
     * @summary Requetes relatives aux requetes.
     * @classdesc Cette classe contient les méthodes implémentant les requetes relatives aux requetes.
     * @arg {string} contextUser - L'identifiant de l'utilisateur du 'context'
     */
    constructor(contextUser) {
        this.contextUser = contextUser;
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function getUserJoinGroupRequest
     * @summary Fonction qui renvoie une requete UserJoinGroup donnée.
     * @arg {number} rid - Identifiant demandé.
     * @return {Promise(UserJoinGroup)} Renvoie la requete dont l'identifiant est 'rid'
     * @async
     * @rights admin du groupe destinaire ou le user émetteur
     */
    getUserJoinGroupRequest(rid) {
        return __awaiter(this, void 0, void 0, function* () {
            return requests_1.UserJoinGroup.tryCreate(rid);
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function getGroupJoinMetagroupRequest
     * @summary Fonction qui renvoie une requete GroupJoinMetagroup donnée.
     * @arg {number} rid - Identifiant demandé.
     * @return {Promise(GroupJoinMetagroup)} Renvoie la requete dont l'identifiant est 'rid'
     * @async
     * @rights admin du groupe émetteur ou destinataire
     */
    getGroupJoinMetagroupRequest(rid) {
        return __awaiter(this, void 0, void 0, function* () {
            return requests_1.GroupJoinMetagroup.tryCreate(rid);
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function getGroupCoauthorEventRequest
     * @summary Fonction qui renvoie une requete GroupCoauthorEvent donnée.
     * @arg {number} rid - Identifiant demandé.
     * @return {Promise(GroupCoauthorEvent)} Renvoie la requete dont l'identifiant est 'rid'
     * @async
     * @rights admin du groupe émetteur ou destinataire
     */
    getGroupCoauthorEventRequest(rid) {
        return __awaiter(this, void 0, void 0, function* () {
            return requests_1.GroupCoauthorEvent.tryCreate(rid);
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function getRequestsToGroup
     * @summary Fonction qui renvoie toutes les requetes destinées a ce groupe.
     * @arg {string} gid - Identifiant du groupe.
     * @return {Promise(Request[])} Renvoie la liste des requetes destinées a ce groupe.
     * @async
     * @rights admin du groupe
     */
    getRequestsToGroup(gid) {
        return __awaiter(this, void 0, void 0, function* () {
            let r1 = yield this.getUserJoinGroupRequestsToGroup(gid);
            let r2 = yield this.getGroupJoinMetagroupRequestsToGroup(gid);
            let r3 = yield this.getGroupCoauthorEventRequestsToGroup(gid);
            let r;
            return r.concat(r1, r2, r3);
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function getUserJoinGroupRequestsToGroup
     * @summary Fonction qui renvoie toutes les requetes UserJoinGroup destinées a ce groupe.
     * @arg {string} gid - Identifiant du groupe.
     * @return {Promise(UserJoinGroup[])} Renvoie la liste des requetes destinées a ce groupe.
     * @async
     * @rights admin du groupe
     */
    getUserJoinGroupRequestsToGroup(gid) {
        return __awaiter(this, void 0, void 0, function* () {
            throw "Not implemented";
            // CODE A MODIFIER
            /*let result = knex.select('id', 'useruid', 'message').from('user_join_group')
                .where('recipient', recipient.gid);
            return result.map(obj => {
                obj.type = "UserJoinGroup";
                return obj;
            });*/
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function getGroupJoinMetagroupRequestsToGroup
     * @summary Fonction qui renvoie toutes les requetes GroupJoinMetagroup destinées a ce groupe.
     * @arg {string} gid - Identifiant du groupe.
     * @return {Promise(GroupJoinMetagroup[])} Renvoie la liste des requetes destinées a ce groupe.
     * @async
     * @rights admin du groupe
     */
    getGroupJoinMetagroupRequestsToGroup(gid) {
        return __awaiter(this, void 0, void 0, function* () {
            throw "Not implemented";
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function getGroupCoauthorEventRequestsToGroup
     * @summary Fonction qui renvoie toutes les requetes GroupCoauthorEvent destinées a ce groupe.
     * @arg {string} gid - Identifiant du groupe.
     * @return {Promise(GroupCoauthorEvent[])} Renvoie la liste des requetes destinées a ce groupe.
     * @async
     * @rights admin du groupe
     */
    getGroupCoauthorEventRequestsToGroup(gid) {
        return __awaiter(this, void 0, void 0, function* () {
            throw "Not implemented";
            //CODE A MODIFIER
            /*let result = await knex.select('id', 'senderuid', 'eventuid', 'message').from('group_join_event')
                .where('recipient', recipient.gid);
            return result.map(obj => {
                obj.type = "GroupJoinEvent";
                return obj;
            });*/
            /*let result = await knex.select('id', 'senderuid', 'eventuid', 'message').from('your_group_host_event')
                .where('recipient', recipient.gid);
            return result.map(obj => {
                obj.type = "YourGroupHostEvent";
                return obj;
            });*/
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function userRequestJoinGroup
     * @summary Fonction pour demander a devenir membre
     * @arg {string} gid - Identifiant du groupe.
     * @arg {string} comment - Commentaire supplémentaire
     * @return {Promise(UserJoinGroup)} Renvoie la requete créée.
     * @async
     * @rights viewer du groupe
     */
    userRequestJoinGroup(gid, comment) {
        return __awaiter(this, void 0, void 0, function* () {
            throw "Not implemented";
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function groupRequestCoauthorEvent
     * @summary Fonction pour demander a co-organiser un évenement
     * @arg {string} from_gid - Identifiant du groupe émetteur.
     * @arg {string} to_gid - Identifiant du groupe destinataire.
     * @arg {number} event_mid - Identifiant de l'évenement considéré.
     * @arg {string} comment - Commentaire supplémentaire.
     * @return {Promise(GroupCoauthorEvent)} Renvoie la requete créée.
     * @async
     * @rights speaker du groupe émetteur
     */
    groupRequestCoauthorEvent(from_gid, to_gid, event_mid, comment) {
        return __awaiter(this, void 0, void 0, function* () {
            //TODO : Vérifier que l'évenement est bien organisé par le groupe destinataire (to_gid) !!! => sinon erreur
            throw "Not implemented";
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function groupRequestJoinMetagroup
     * @summary Fonction pour demander a rejoindre un méta-groupe
     * @arg {string} from_gid - Identifiant du groupe émetteur.
     * @arg {string} to_gid - Identifiant du méta-groupe destinataire.
     * @arg {string} comment - Commentaire supplémentaire.
     * @return {Promise(GroupJoinMetagroup)} Renvoie la requete créée.
     * @async
     * @rights admin du groupe émetteur
     */
    groupRequestJoinMetagroup(from_gid, to_gid, comment) {
        return __awaiter(this, void 0, void 0, function* () {
            throw "Not implemented";
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function acceptUserJoinRequest
     * @summary Fonction pour accepter une UserJoinGroup
     * @arg {UserJoinGroup} req - L'objet requete.
     * @arg {string} comment - Commentaire supplémentaire.
     * @return {Promise(boolean)} Renvoie true si modification réussie.
     * @async
     * @rights admin du groupe destinataire
     */
    acceptUserJoinRequest(req, comment) {
        return __awaiter(this, void 0, void 0, function* () {
            //"comment" a envoyer par mail automatique
            throw "Not implemented";
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function refuseUserJoinRequest
     * @summary Fonction pour refuser une UserJoinGroup
     * @arg {UserJoinGroup} req - L'objet requete.
     * @arg {string} comment - Commentaire supplémentaire.
     * @return {Promise(boolean)} Renvoie true si modification réussie.
     * @async
     * @rights admin du groupe destinataire
     */
    refuseUserJoinRequest(req, comment) {
        return __awaiter(this, void 0, void 0, function* () {
            //"comment" a envoyer par mail automatique
            throw "Not implemented";
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function acceptGroupJoinRequest
     * @summary Fonction pour accepter une GroupJoinMetagroup
     * @arg {GroupJoinMetagroup} req - L'objet requete.
     * @arg {string} comment - Commentaire supplémentaire.
     * @return {Promise(boolean)} Renvoie true si modification réussie.
     * @async
     * @rights admin du groupe destinataire
     */
    acceptGroupJoinRequest(req, comment) {
        return __awaiter(this, void 0, void 0, function* () {
            //"comment" a envoyer par mail automatique
            throw "Not implemented";
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function refuseGroupJoinRequest
     * @summary Fonction pour refuser une GroupJoinMetagroup
     * @arg {GroupJoinMetagroup} req - L'objet requete.
     * @arg {string} comment - Commentaire supplémentaire.
     * @return {Promise(boolean)} Renvoie true si modification réussie.
     * @async
     * @rights admin du groupe destinataire
     */
    refuseGroupJoinRequest(req, comment) {
        return __awaiter(this, void 0, void 0, function* () {
            //"comment" a envoyer par mail automatique
            throw "Not implemented";
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function acceptGroupCoauthorEventRequest
     * @summary Fonction pour accepter une GroupCoauthorEvent
     * @arg {GroupCoauthorEvent} req - L'objet requete.
     * @arg {string} comment - Commentaire supplémentaire.
     * @return {Promise(boolean)} Renvoie true si modification réussie.
     * @async
     * @rights admin du groupe destinataire
     */
    acceptGroupCoauthorEventRequest(req, comment) {
        return __awaiter(this, void 0, void 0, function* () {
            //"comment" a envoyer par mail automatique
            throw "Not implemented";
            /*let request = await knex('group_join_event').select().where('id', requestID);
            if (!request.length)
                return false;
            
            let group = request[0].senderuid;
            let event = request[0].eventuid;
            await knex('group_participation').insert({
                group: group,
                message: event,
                status: "join"
            });
            await knex('group_join_event').where('id', requestID).del();
            return;*/
        });
    }
    /**
     * @memberof GraphQL.RequestModel#
     * @function refuseGroupCoauthorEventRequest
     * @summary Fonction pour refuser une GroupCoauthorEvent
     * @arg {GroupCoauthorEvent} req - L'objet requete.
     * @arg {string} comment - Commentaire supplémentaire.
     * @return {Promise(boolean)} Renvoie true si modification réussie.
     * @async
     * @rights admin du groupe destinataire
     */
    refuseGroupCoauthorEventRequest(req, comment) {
        return __awaiter(this, void 0, void 0, function* () {
            //"comment" a envoyer par mail automatique
            throw "Not implemented";
            /*await knex('group_join_event').where('id', requestID).del();
            //KNEX RENVOIE LE NOMBRE DE LIGNES AFFECTÉES -> il faut l'utiliser pour la valeur de retour
            return true;*/
        });
    }
}
exports.RequestModel = RequestModel;
//# sourceMappingURL=requestModel.js.map